MailSlurpAPI.Api.SentEmailsController (mailslurp v12.8.4)
API calls for all endpoints tagged SentEmailsController.
Link to this section Summary
Functions
Get all sent email tracking pixels in paginated form
Get sent email receipt
Get sent email HTML content
Get all tracking pixels for a sent email in paginated form
Get all sent emails in paginated form
Get all sent organization emails in paginated form
Link to this section Functions
get_all_sent_tracking_pixels(connection, opts \\ [])
Specs
get_all_sent_tracking_pixels(Tesla.Env.client(), keyword()) :: {:ok, MailSlurpAPI.Model.PageTrackingPixelProjection.t()} | {:error, Tesla.Env.t()}
Get all sent email tracking pixels in paginated form
Parameters
- connection (MailSlurpAPI.Connection): Connection to server
- opts (KeywordList): [optional] Optional parameters
} on success {:error, info} on failure
get_sent_email(connection, id, opts \\ [])
Specs
get_sent_email(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MailSlurpAPI.Model.SentEmailDto.t()} | {:error, Tesla.Env.t()}
Get sent email receipt
Parameters
- connection (MailSlurpAPI.Connection): Connection to server
- id (String.t): id
- opts (KeywordList): [optional] Optional parameters
Returns
} on success {:error, info} on failure
get_sent_email_html_content(connection, id, opts \\ [])
Specs
get_sent_email_html_content(Tesla.Env.client(), String.t(), keyword()) :: {:ok, String.t()} | {:error, Tesla.Env.t()}
Get sent email HTML content
Parameters
- connection (MailSlurpAPI.Connection): Connection to server
- id (String.t): id
- opts (KeywordList): [optional] Optional parameters
Returns
} on success {:error, info} on failure
get_sent_email_tracking_pixels(connection, id, opts \\ [])
Specs
get_sent_email_tracking_pixels(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MailSlurpAPI.Model.PageTrackingPixelProjection.t()} | {:error, Tesla.Env.t()}
Get all tracking pixels for a sent email in paginated form
Parameters
- connection (MailSlurpAPI.Connection): Connection to server
- id (String.t): id
- opts (KeywordList): [optional] Optional parameters
} on success {:error, info} on failure
get_sent_emails(connection, opts \\ [])
Specs
get_sent_emails(Tesla.Env.client(), keyword()) :: {:ok, MailSlurpAPI.Model.PageSentEmailProjection.t()} | {:error, Tesla.Env.t()}
Get all sent emails in paginated form
Parameters
- connection (MailSlurpAPI.Connection): Connection to server
- opts (KeywordList): [optional] Optional parameters
- :inbox_id (String.t): Optional inboxId to filter sender of sent emails by
- :page (integer()): Optional page index in inbox sent email list pagination
- :search_filter (String.t): Optional search filter
- :size (integer()): Optional page size in inbox sent email list pagination
- :sort (String.t): Optional createdAt sort direction ASC or DESC
Returns
} on success {:error, info} on failure
get_sent_organization_emails(connection, opts \\ [])
Specs
get_sent_organization_emails(Tesla.Env.client(), keyword()) :: {:ok, MailSlurpAPI.Model.PageSentEmailProjection.t()} | {:error, Tesla.Env.t()}
Get all sent organization emails in paginated form
Parameters
- connection (MailSlurpAPI.Connection): Connection to server
- opts (KeywordList): [optional] Optional parameters
- :inbox_id (String.t): Optional inboxId to filter sender of sent emails by
- :page (integer()): Optional page index in sent email list pagination
- :search_filter (String.t): Optional search filter
- :size (integer()): Optional page size in sent email list pagination
- :sort (String.t): Optional createdAt sort direction ASC or DESC
Returns
} on success {:error, info} on failure