MailSlurpAPI.Model.WebhookEmailOpenedPayload (mailslurp v12.8.4)
EMAIL_OPENED webhook payload. Sent to your webhook url endpoint via HTTP POST when an email containing a tracking pixel is opened and the pixel image is loaded by a reader.
Link to this section Summary
Link to this section Types
Specs
t() :: %MailSlurpAPI.Model.WebhookEmailOpenedPayload{
createdAt: DateTime.t() | nil,
eventName: String.t() | nil,
inboxId: String.t() | nil,
messageId: String.t() | nil,
pixelId: String.t() | nil,
recipient: String.t() | nil,
sentEmailId: String.t() | nil,
webhookId: String.t() | nil,
webhookName: String.t() | nil
}