MailSlurpAPI.Model.WebhookNewContactPayload (mailslurp v12.4.2)
NEW_CONTACT webhook payload. Sent to your webhook url endpoint via HTTP POST when an email is received by the inbox that your webhook is attached to that contains a recipient that has not been saved as a contact.
Link to this section Summary
Link to this section Types
Specs
t() :: %MailSlurpAPI.Model.WebhookNewContactPayload{
company: String.t() | nil,
contactId: String.t(),
createdAt: DateTime.t(),
emailAddresses: [String.t()],
eventName: String.t() | nil,
firstName: String.t() | nil,
groupId: String.t() | nil,
lastName: String.t() | nil,
messageId: String.t() | nil,
metaData: Map | nil,
optOut: boolean() | nil,
primaryEmailAddress: String.t() | nil,
tags: [String.t()],
webhookId: String.t() | nil,
webhookName: String.t() | nil
}